@@ -31,8 +31,16 @@ class Bucket(core.Construct):
         
         app_name (str): The application name. This will be used to generate the 'ApplicationName' tag for CSI compliancy. The ID of the application. This must be unique for each system, as it will be used to calculate the AWS costs of the system
 
+        environment (str): Specify the environment in which you want to deploy you system. Allowed values: Development, QA, Production, SharedServices 
+
+        environments_parameters (dict): The dictionary containing the references to CSI AWS environments. This will simplify the environment promotions and enable a parametric development of the infrastructures.
+
         bucket_name (str): The S3 Bucket in which the application S3 are stored
         
+        bucket_is_public (str): Wheather or not the S3 bucket should be public
+
+        bucket_is_privately_accessed_from_vpc_over_http_over_http (str): Force the bucket to be private and enable HTTP private accessed from within the VPC. When this parameter is set to True, `bucket_is_public` and `bucket_has_cdn` will be forced to be False
+        
         bucket_has_cdn (str): Wheather or not the S3 bucket will be serverd by a Cloudflare CDN
         
         bucket_website_index_document (str): Use this parameter to configure the S3 bucket as Web Hosting. This is the S3 key of the index document of your static site (generally is index.html)
@@ -105,11 +113,13 @@ class Bucket(core.Construct):
         id: str,
         app_name,
         environment,
+        environments_parameters,
         bucket_name,
         bucket_is_public="False",
         bucket_has_cdn="False",
         bucket_website_index_document=None,
         bucket_website_error_document=None,
+        bucket_is_privately_accessed_from_vpc_over_http=False,
         **kwargs
     ):
         super().__init__(scope, id, **kwargs)
@@ -121,6 +131,10 @@ class Bucket(core.Construct):
         # Declare variables
         self.bucket = None
 
+        environment = environment.lower()
+        aws_account = environments_parameters["accounts"][environment]
+        account_id = aws_account["id"]
+
         # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ Create conditions
         # bucket_name_was_provided = bucket_name.strip()
         # bucket_already_exist = check_if_bucket_exist(
@@ -162,6 +176,24 @@ class Bucket(core.Construct):
             block_public_access=_s3.BlockPublicAccess.BLOCK_ALL if not public_read_access else None,  # https://docs.aws.amazon.com/AmazonS3/latest/dev/access-control-block-public-access.html
         )
 
+        if bucket_is_privately_accessed_from_vpc_over_http:
+            # Force public read to false
+            public_read_access=False
+            bucket_has_cdn=False
+
+            self.bucket.add_to_resource_policy(
+                _iam.PolicyStatement(
+                    principals=[_iam.Anyone()],
+                    actions=["s3:GetObject"],
+                    resources=[
+                        "arn:aws:s3:::" + bucket_name,
+                        "arn:aws:s3:::" + bucket_name + "/*",
+                    ],
+                    #conditions={"StringEquals": {"aws:sourceVpce": aws_account["vpc"]}},
+                )
+            )
+
+
         if public_read_access:
             # Grant access to anyone
             self.bucket.grant_public_access()
